=======
Credits
=======

Development Lead
----------------

* GoTLiuM InSPiRiT <gotlium@gmail.com>

Contributors
------------

* Grokzen <grokzen@gmail.com>
* Philipp Schmitt <philipp@schmitt.co>
* Tom Horlock <thomashorlock1993@gmail.com>
* Evgeniy Poturaev <gig177@ya.ru>
